@@ -8,34 +8,39 @@ from mkdocs_expose_page_metadata.metadata_parser import MetadataParser
 
 class MetadataPage:
 
+    # CONSTANTS
+
     PATH = "metadata"
     NAME = "metadata.json"
     ENCODE = "utf-8"
 
+    # CONSTRUCTOR
+
     def __init__(self, path: str, name: str, encode: str):
         self._PATH = path if path else self.PATH
         self._NAME = name if name else self.NAME
         self._ENCODE = encode if encode else self.ENCODE
-        self._CONTENT = list[MetadataPageEntry]()
+        self._ENTRIES = list[MetadataPageEntry]()
+
+    # METHODS
 
     def append_content_from(self, page: Page):
 
         if page.meta:
-            entry = MetadataPageEntry(title=page.title, url=page.url, meta=page.meta)
-            self._CONTENT.append(entry)
+            entry = MetadataPageEntry(title=page.title, location=page.url, meta=page.meta)
+            self._ENTRIES.append(entry)
 
         parser = MetadataParser(page)
 
         for entry in parser.entries:
-            if (not entry.url):
-                raise Exception(f"URL not found for subtitle \"{_SUBTITLE}\" on page \"{page.title}\"")
-            self._CONTENT.append(entry)
-
+            if (not entry.location):
+                raise Exception(f"Location not found for subtitle \"{entry.title}\" on page \"{page.title}\"")
+            self._ENTRIES.append(entry)
 
     def save(self):
-        _ENDPOINT = os.path.join(self._PATH, self._NAME)
-        _CONTENT = self.__str__()
-        utils.write_file(_CONTENT.encode(self._ENCODE), _ENDPOINT)
-
+        endpoint = os.path.join(self._PATH, self._NAME)
+        content = self.__str__()
+        utils.write_file(content.encode(self._ENCODE), endpoint)
+    
     def __repr__(self) -> str:
-        return to_json([entry.to_dict() for entry in self._CONTENT])
+        return to_json([entry.to_dict() for entry in self._ENTRIES])
