@@ -2,26 +2,32 @@ from mkdocs_expose_page_metadata.metadata import Metadata
 
 class MetadataPageEntry:
 
+    # PROPERTIES
+
     @property
     def title(self) -> str:
         return self._TITLE
 
     @property
-    def url(self) -> str:
-        return self._URL
+    def location(self) -> str:
+        return self._LOCATION
 
     @property
     def meta(self) -> Metadata:
         return self._META
 
-    def __init__(self, title: str, url: str, meta: dict=None, annotations: list[str] = []):
+    # CONSTRUCTOR
+
+    def __init__(self, title: str, location: str, meta: dict=None, annotations: list[str] = []):
         self._TITLE = title
-        self._URL = url
+        self._LOCATION = location
         self._META = Metadata(content=meta, annotations=annotations)
 
+    # METHODS
+
     def to_dict(self):
         return {
             'title': self.title,
-            'url': self.url,
+            'location': self.location,
             'meta': self.meta.content
         }
